# -*- coding:utf-8 -*-

questions = [
    {'name': 'China','demonym': 'Chinese','state': 'Asia','language': 'Chinese','currency': 'RMB','capital': 'BeiJing',},
    {
        'name': 'Indonesia',
        'demonym': 'Indonesian',
        'state': 'Asia',
        'language': 'Indonesian',
        'currency': 'rupiah',
        'capital': 'Jakarta',
    },
    {
        'name': 'Germany',
        'state': 'Europe',
        'capital': 'Berlin',
        'language': 'German',
        'demonym': 'German',
        'currency': 'Euro',
    },
    {
        'name': 'Canada',
        'state': 'North America',
        'capital': 'Ottawa',
        'language': 'English and French',
        'demonym': 'Canadian',
        'currency': 'Canadian dollar',
    },
    {
        'name': 'Iran',
        'state': 'Asia',
        'capital': 'Tehran',
        'language': 'Persian',
        'demonym': 'Iranian',
        'currency': 'Rial',
    },
    {'name': 'Thailand','demonym': 'Thai','state': 'Asia','language': 'Thai','currency': 'Baht','capital': 'Bangkok',},
    {'name': 'Chile','demonym': 'Chilean','state': 'South American','language': 'Spanish','currency': 'Peso','capital': 'Santiago',},
    {'name': 'Brazil','demonym': 'Brazilian','state': 'South America','language': 'Portuguese','currency': 'Real','capital': u'Brasília',},
    # {'name': '','demonym': '','state': '','language': '','currency': '','capital': '',},
]